"""XP CLI tool for remote console bus operations"""
"""My Package - A sample Python package."""

__version__ = "0.9.2"
__manufacturer__ = "ldvchosal"
__model__ = "xp.cli"
__serial__ = "2025.09.23.000"